%author Veronica Martinez, The University of Queensland, AIBN
%13-March-2014

% to generate the dataset of the yeast example

clear all;clc
global a12 a32 b11 b21 b22 b31 ks ko kp Ks Ko Kp Ki y1 y2 y3

a12=12.4; % mmoles/g of glucose
a32=34.5; % mmoles/g of Ethanol
b11=13.4; % mmoles/g of glucose
b21=10.5; %mmoles/g of glucose
b22=0.48; %g/g of glucose
b31=14.2; % mmoles/g of ethanol

y1=0.49; % g/g of glucose
y2=0.05; % g/g of glucose
y3=0.72; % g/g of ethanol

ks=3.5; % g/(g*h)
ko=8; % mmoles/(g*h)
kp=0.17; % g/(g*h)
Ks=0.1; % g/L
Ko=0.1; % mg/L
Kp=0.1; % g/L
Ki=0.1; % g/L

%Co=[2,0,0.1,100];
Co=[2,0,0.1];
%t=0:1/6:5;
%t=[t 5.5:0.5:15];
%t=0:1/6:15;
options=odeset('NonNegative',1:3);

[t,y]=ode45(@YeastGlucEthanol,[0:0.5:15],Co,options);

tr=t;
% Estimate rates of o2 consumption and co2 production
s=y(:,1);
p=y(:,2);
x=y(:,3);

rs=ks*(s./(s+Ks)); %glucose rate
romax=8;
rppot=kp.*(p./(p+Kp)).*(1./(1+(s./Ki))); % potential ethanol rate
r1=min(rs,romax/a12); % the oxidative glucose metabolism as the minimun between glocuse flux and the oxidative capacity
r2=zeros(length(rs),1);
r3=zeros(length(rs),1);
for i=1:length(rs)
    if rs(i)>(romax/a12)
        r2(i)=rs(i)-(romax/a12); % the excess of glucose rate goes to ethanol production (fermentative metabolism)
    else
        r3(i)=min(rppot(i),(romax-a12*rs(i))/a32);
    end
end

ro=(a12*r1+a32*r3).*x; %specific rate of o2
rc=(b11*r1+b21*r2+b31*r3).*x; % specific rate of co2


cm=[s p x];
rm=[-ro rc];
stdev=0.05*cm;
stdevR=0.05*abs(rm);
stdev(find(stdev<0.01))=0.01;
stdevR(find(stdevR<0.01))=0.01;

S=[-1 -1 0; -a12 0 -a32;0 b22 -1;b11 b21 b31;y1 y2 y3];
preR=[zeros(size(S)) -1*eye(size(cm,2)+size(rm,2))];
S=[S eye(size(cm,2)+size(rm,2))];
S(:,6:8)=-S(:,6:8);
R=[preR(1,:) ;-1*preR(3,:); -1*preR(5,:)];
Rr=[preR(2,:);-preR(4,:)];