%author Veronica Martinez, The University of Queensland, AIBN
%25-Sept-2013

% to generate the dataset of the yeast example

function f=YeastGlucEthanol(t,y)
% Sonnleitner and Kappeli model (1986), og glucose/ethanol
% consumption/production based in a limited oxidative capacity
%Substrates: Glucose(s), Oxygen (So)
%Products: Ethanol (p)which can be substrate in some scenarios and Co2 (pc)

global a12 a32 b11 b21 b22 b31 ks ko kp Ks Ko Kp Ki y1 y2 y3

s=y(1);
p=y(2);
x=y(3);

rs=ks*(s/(s+Ks)); %glucose rate
romax=8;
rppot=kp*(p/(p+Kp))*(1/(1+(s/Ki))); % potential ethanol rate
r1=min(rs,(romax/a12)); % the oxidative glucose metabolism as the minimun between glocuse flux and the oxidative capacity

r2=0;
r3=0;
if rs>(romax/a12)
    r2=rs-(romax/a12); % the excess of glucose rate goes to ethanol production (fermentative metabolism)
else
    r3=min(rppot,(romax-(a12*rs))/a32); % ethanol consumption when there is remaining oxidative capacity
end
% mass balance

dsdt=-(r1+r2)*x;%+D*(sf-s);
dpdt=(b22*r2-r3)*x;%-Dp;
dxdt=(y1*r1+y2*r2+y3*r3)*x;%-D*x; % biomass

f(1)=dsdt;
f(2)=dpdt;
f(3)=dxdt;

f=f';









    






